@@ -3,12 +3,10 @@ Exports the libgeos_c shared lib, GEOS-specific exceptions, and utilities.
 """
 
 import atexit
-from ctypes import cdll, CDLL, pydll, PyDLL, CFUNCTYPE, c_char_p
-from ctypes.util import find_library
 import os
 import sys
-
-import shapely
+from ctypes import cdll, CDLL, PyDLL, CFUNCTYPE, c_char_p
+from ctypes.util import find_library
 
 if sys.platform == 'win32':
     try:
@@ -31,13 +29,15 @@ elif sys.platform == 'darwin':
         lib_paths = [
             # The Framework build from Kyng Chaos:
             "/Library/Frameworks/GEOS.framework/Versions/Current/GEOS",
+            # macports
+            '/opt/local/lib/libgeos_c.dylib',
         ]
         for path in lib_paths:
             if os.path.exists(path):
                 lib = path
                 break
-            else:
-                raise ImportError, "Could not find geos_c library"
+    if lib is None:
+        raise ImportError, "Could not find geos_c library"
     lgeos = PyDLL(lib)
     free = CDLL(find_library('libc')).free
 else:
@@ -51,6 +51,10 @@ else:
     free = CDLL('libc.so.6').free
 
 
+# Load the ctypes restype and argtype declarations for geos_c functions.
+_here = os.path.abspath(os.path.dirname(__file__))
+execfile(os.path.join(_here, 'ctypes_declarations.py'))
+
 class allocated_c_char_p(c_char_p):
     pass
 
@@ -83,10 +87,9 @@ notice_h = CFUNCTYPE(None, c_char_p, c_char_p)(notice_handler)
 # Register a cleanup function
 
 def cleanup():
-    lgeos.finishGEOS()
+    if lgeos is not None:
+        lgeos.finishGEOS()
 
 atexit.register(cleanup)
 
 lgeos.initGEOS(notice_h, error_h)
-
-
